@@ -38,7 +38,7 @@ from .utils import (
 
 __author__ = "Samuel Bradley"
 __email__ = "sam.bradley@csiro.au"
-__version__ = "1.5.0"
+__version__ = "1.7.2"
 
 
 def create_app(
@@ -60,9 +60,11 @@ def create_app(
     app = FastAPI(title=settings.PROJECT_NAME, openapi_url=f"{settings.API_PRE_PATH}/openapi.json", **kwargs)
 
     if settings.ROLLBAR_KEY is not None:
+        from rollbar.contrib.fastapi import LoggerMiddleware
         from rollbar.contrib.fastapi import add_to as rollbar_add_to
 
         rollbar_add_to(app)
+        app.add_middleware(LoggerMiddleware)
 
     # CORS
     origins = []
@@ -88,14 +90,14 @@ def create_app(
         app.add_middleware(GZipMiddleware, minimum_size=5000)
 
     if settings.SECURE:
-        from secure import SecureCookie, SecureHeaders
+        import secure
 
-        secure_headers = SecureHeaders()
+        secure_headers = secure.Secure()
 
         @app.middleware("http")
         async def set_secure_headers(request, call_next):
             response = await call_next(request)
-            secure_headers.starlette(response)
+            secure_headers.framework.fastapi(response)
             return response
 
     @app.on_event("startup")
