@@ -27,12 +27,13 @@ class AuthType(str, Enum):
 
 
 class Settings(BaseSettings):
-    VERSION: str = "1.5.0"
+    VERSION: str = "1.7.2"
     API_VERSION: int = 1
     API_PRE_PATH: str = f"/api/v{API_VERSION}"
 
     SECURE = False  # Use secure.py (set to true for prod)
     ROLLBAR_KEY: Optional[str] = None
+    ROLLBAR_LOG_LEVEL: int = logging.ERROR
     DEBUG: bool = False
     UNIT_TESTING: bool = False
     ENVIRONMENT: str = "local"
@@ -81,7 +82,7 @@ class Settings(BaseSettings):
     MONGO_AUTO_CONNECT: bool = True
     mongodb_min_pool_size: int = 0
     mongodb_max_pool_size: int = 100
-    TZ: str = "Australia/Perth"
+    TZ: str = "UTC"
     APP_PATH: str = "fa_common"
     FASTAPI_APP: str = ""
 
@@ -91,17 +92,6 @@ class Settings(BaseSettings):
         env_file = ".env"
         env_file_encoding = "utf-8"
 
-    # class Config:
-    #     env_prefix = 'FA_COMMON_'  # defaults to no prefix, i.e. ""
-    #     fields = {
-    #         'auth_key': {
-    #             'env': 'my_auth_key',
-    #         },
-    #         'redis_dsn': {
-    #             'env': ['service_redis_dsn', 'redis_url']
-    #         }
-    #     }
-
 
 settings: Optional[Settings] = None
 
