@@ -1,15 +1,7 @@
 import abc
 from typing import Any, List, Optional, Tuple, Type
 
-from .models import (
-    DBIndex,
-    DeleteResult,
-    DocumentDBModel,
-    FireOffset,
-    SortOrder,
-    WhereCondition,
-    WriteResult,
-)
+from .models import DBIndex, DeleteResult, DocumentDBModel, FireOffset, SortOrder, WhereCondition, WriteResult
 
 
 class BaseClient(abc.ABC):
@@ -88,7 +80,6 @@ class BaseClient(abc.ABC):
         Returns:
             Cursor -- [description]
         """
-        pass
 
     @abc.abstractmethod
     async def delete(self, model: Type[DocumentDBModel], _id: str, session: Any = None) -> DeleteResult:
