@@ -1,4 +1,5 @@
 import traceback
+from typing import Any, Dict, List
 
 from fastapi import FastAPI
 from fastapi.exceptions import RequestValidationError
@@ -6,6 +7,9 @@ from pydantic import ValidationError
 from starlette.exceptions import HTTPException as StarletteHTTPException
 from starlette.requests import Request
 
+from fa_common.exceptions import RuleValidationError
+
+from .config import get_settings
 from .responses import UJSONResponse
 from .utils import logger as LOG
 
@@ -41,9 +45,14 @@ async def validation_exception_handler(request: Request, exc: RequestValidationE
     :param exc: StarletteHTTPException instance
     :return: UJSONResponse with newly formatted error data
     """
+    if get_settings().ROLLBAR_KEY is not None:
+        import rollbar
+
+        rollbar.report_message(f"RequestValidationError Caught: {exc}", "warning")
+
     LOG.warning(f"RequestValidationError Caught: {exc}")
     status_code = getattr(exc, "status_code", 422)
-    errors = []
+    errors: List[Dict[str, Any]] = []
     details = str(exc)
     try:
         errors.extend(
@@ -74,6 +83,11 @@ async def pydantic_validation_exception_handler(request: Request, exc: Validatio
     :param exc: StarletteHTTPException instance
     :return: UJSONResponse with newly formatted error data
     """
+    if get_settings().ROLLBAR_KEY is not None:
+        import rollbar
+
+        rollbar.report_exc_info()
+
     LOG.error(f"Unhandled Pydantic ValidationError Caught: {str(exc)}")
     # errors = []
     # try:
@@ -99,18 +113,39 @@ async def pydantic_validation_exception_handler(request: Request, exc: Validatio
 
 
 async def assert_exception(request: Request, exc: AssertionError) -> UJSONResponse:
+    if get_settings().ROLLBAR_KEY is not None:
+        import rollbar
+
+        rollbar.report_message(f"Assert exception caught: {str(exc)}", "warning")
+
     LOG.warning(f"Assert exception caught: {str(exc)}")
     data = {"code": "Assertion Error", "detail": str(exc)}
     return UJSONResponse(data, status_code=400, headers={"Access-Control-Allow-Origin": "*"})
 
 
+async def rule_exception(request: Request, exc: RuleValidationError) -> UJSONResponse:
+    if get_settings().ROLLBAR_KEY is not None:
+        import rollbar
+
+        rollbar.report_message(f"Rule Validation error caught: {str(exc)}", "warning")
+
+    LOG.warning(f"Rule Validation caught: {str(exc)}")
+    data = {"code": "Rule Validation Error", "detail": str(exc)}
+    return UJSONResponse(data, status_code=400, headers={"Access-Control-Allow-Origin": "*"})
+
+
 async def default_exception(request: Request, exc: Exception) -> UJSONResponse:
+    if get_settings().ROLLBAR_KEY is not None:
+        import rollbar
+
+        rollbar.report_exc_info()
     LOG.error(f"Internal exception caught: {exc}")
     data = {
         "code": "Internal Server Error",
         "detail": str(exc),
         "trace": traceback.format_exc(),
     }
+
     return UJSONResponse(data, status_code=500, headers={"Access-Control-Allow-Origin": "*"})
 
 
@@ -134,4 +169,5 @@ def setup_exception_handlers(app: FastAPI) -> None:
     app.add_exception_handler(RequestValidationError, validation_exception_handler)
     app.add_exception_handler(ValidationError, pydantic_validation_exception_handler)
     app.add_exception_handler(AssertionError, assert_exception)
+    app.add_exception_handler(RuleValidationError, rule_exception)
     app.add_exception_handler(Exception, default_exception)
