@@ -1,5 +1,6 @@
 from datetime import date, datetime, time
 
+from bson import ObjectId
 from humps.camel import case
 from pydantic import BaseModel
 
@@ -18,7 +19,10 @@ class CamelModel(BaseModel):
             datetime: lambda dt: dt.replace(microsecond=0, tzinfo=get_timezone()).isoformat(),
             date: lambda date: date.isoformat(),
             time: lambda time: time.replace(microsecond=0, tzinfo=get_timezone()).isoformat(),
+            ObjectId: lambda v: str(v),
         }
+        # Needed for the _id to be included when serialised; can't work out how to rename it `id`
+        fields = {"id": "_id"}
 
 
 class FileDownloadRef(CamelModel):
