@@ -10,6 +10,7 @@ from typing import Any, Optional
 import aiohttp
 import pytz
 from fastapi import FastAPI
+from rollbar.logger import RollbarHandler
 
 from .config import get_settings
 
@@ -65,6 +66,13 @@ def get_logger() -> Any:
 
         lib_logger.configure(**logger_config)  # type: ignore
 
+        # Enable logging to Rollbar
+        if get_settings().ROLLBAR_LOG_LEVEL is not None and get_settings().ROLLBAR_KEY is not None:
+            level = get_settings().ROLLBAR_LOG_LEVEL
+            rollbar_handler = RollbarHandler()
+            rollbar_handler.setLevel(level)
+            lib_logger.add(rollbar_handler, level=level)
+
     return lib_logger
 
 
