@@ -1,7 +1,7 @@
+import oyaml as yaml
 from fastapi import FastAPI
 
 from fa_common import get_current_app, get_settings, logger
-import oyaml as yaml
 
 
 def setup_gitlab(app: FastAPI) -> None:
@@ -28,9 +28,7 @@ def setup_gitlab(app: FastAPI) -> None:
     ):
         import gitlab
 
-        gl = gitlab.Gitlab(
-            settings.GITLAB_URL, private_token=settings.GITLAB_PRIVATE_TOKEN
-        )
+        gl = gitlab.Gitlab(settings.GITLAB_URL, private_token=settings.GITLAB_PRIVATE_TOKEN)
         app.gitlab = gl  # type:ignore
         logger.info("Gitlab client has been setup")
 
